summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorcheapie <no-email-for-you@example.com>2016-09-19 21:50:08 -0500
committercheapie <no-email-for-you@example.com>2016-09-19 21:50:08 -0500
commit2fee00a047903ff3fc5c77a603036b58512e0ca1 (patch)
tree4cc7ff7db3a739316dec88c59e5a6e9842a4665e
parentddc2fed862ae681af5f404a81791981afac7df1d (diff)
downloadroads-2fee00a047903ff3fc5c77a603036b58512e0ca1.tar
roads-2fee00a047903ff3fc5c77a603036b58512e0ca1.tar.gz
roads-2fee00a047903ff3fc5c77a603036b58512e0ca1.tar.bz2
roads-2fee00a047903ff3fc5c77a603036b58512e0ca1.tar.xz
roads-2fee00a047903ff3fc5c77a603036b58512e0ca1.zip
Fix crash on newer servers
-rw-r--r--infrastructure/settings.lua6
1 files changed, 3 insertions, 3 deletions
diff --git a/infrastructure/settings.lua b/infrastructure/settings.lua
index 1433e22..7ab8213 100644
--- a/infrastructure/settings.lua
+++ b/infrastructure/settings.lua
@@ -35,7 +35,7 @@
CURVE_CHEVRON_LIGHT_RANGE = 12 -- an integer -> default = 12 | How much light do you want it to give?
-- Crosswalk lighting
- CROSSWALK_LIGHTING_LIGHT_RANGE = 15 -- an integer -> default = 15 | How much light do you want it to give?
+ CROSSWALK_LIGHTING_LIGHT_RANGE = 14 -- an integer -> default = 14 | How much light do you want it to give?
-- Crosswalk safety sign
CROSSWALK_SAFETY_SIGN_LIGHT_RANGE = 8 -- an integer -> default = 8 | How much light do you want it to give?
@@ -44,6 +44,6 @@
RETROREFLECTIVE_SURFACE_LIGHT_RANGE = 8 -- an integer -> default = 8 | How much light do you want it to give?
-- Aircraft warning light
- AIRCRAFT_WARNING_LIGHT_LIGHT_RANGE = 15 -- an integer -> default = 15 | How much light do you want it to give?
+ AIRCRAFT_WARNING_LIGHT_LIGHT_RANGE = 14 -- an integer -> default = 14 | How much light do you want it to give?
-- Warning light
- WARNING_LIGHT_LIGHT_RANGE = 15 -- an integer -> default = 15 | How much light do you want it to give?
+ WARNING_LIGHT_LIGHT_RANGE = 14 -- an integer -> default = 14 | How much light do you want it to give?